@@ -34,7 +34,8 @@ class Aptly(Cmd):
         self.prompt = '<aptly> '
         self.intro = ("Aptly 2010.5.15\n"
                       "Type 'help' for more information or 'quit' to exit.")
-        self.known_commands = ['help', 'install', 'update', 'remove', 'prompt', 'set', 'quit']
+        self.known_commands = ['help', 'install', 'update', 'remove', 'list', 
+			       'prompt', 'set', 'quit']
         self.commands = []
         self.ready = False
 
@@ -118,8 +119,6 @@ class Aptly(Cmd):
 
             Popen(' '.join(['apt-get', 'install', config.main['options']] + remote),
                   shell=True).communicate()
-
-
         else:
             packages = raw_input('What package(s) would you like to install?\n'
                                  '===> ')
@@ -136,7 +135,7 @@ class Aptly(Cmd):
         packages = packages.replace(',', ' ').split()
 
         if packages:
-            Popen(['apt-get', 'remove'] + packages, stdout=PIPE).communicate()
+            Popen(['apt-get', 'remove'] + packages).communicate()
         else:
             packages = raw_input('What package(s) would you like to remove?\n'
                                  '===> ')
@@ -164,6 +163,7 @@ class Aptly(Cmd):
         Popen(['apt-get', 'upgrade']).communicate()
 
     def do_list(self, packages):
+	print 'line 168'
         packages = packages.replace(',', ' ').split()
 
         for package in packages:
